@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2013 Olivier Girondel
+ *  Copyright 1994-2014 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -57,7 +57,7 @@ Schemes_random(Context_t *ctx)
 
 	/* if ((res == -1) && (schemes->schemes[random][i].p == 1.0)) { */
 	/* this is the correct way to check with floats: */
-	if ((res == -1) && (fabsf(schemes->schemes[random][i].p - 1.0) <= FLT_EPSILON)) {
+	if ((res == -1) && (fabs(schemes->schemes[random][i].p - 1.0) <= FLT_EPSILON)) {
 	  /* could not find a mandatory plugin */
 #ifdef DEBUG
 	  printf("[!] Marking scheme %d as invalid.\n", random);
